{
  config,
  pkgs,
  ...
}: {
  sops.templates = let
    placeholder = config.sops.placeholder;
  in {
    "home.nmconnection".content = ''
      [connection]
      id=${placeholder."home/ssid"}
      type=wifi

      [wifi]
      mode=infrastructure
      ssid=${placeholder."home/ssid"}

      [wifi-security]
      key-mgmt=wpa-psk
      psk=${placeholder."home/psk"}
    '';
    "eduroam.nmconnection".content = ''
      [connection]
      id=eduroam
      type=wifi

      [wifi]
      mode=infrastructure
      ssid=eduroam

      [wifi-security]
      auth-alg=open
      key-mgmt=wpa-eap

      [802-1x]
      anonymous-identity=anonymous@uni-hannover.de
      ca-cert=${./T-TeleSec_GlobalRoot_Class_2.crt}
      domain-suffix-match=radius-dfn.luis.uni-hannover.de
      eap=ttls;
      identity=${placeholder."eduroam/ident"}
      password=${placeholder."eduroam/psk"}
      phase2-auth=mschapv2
    '';
  };
  environment.etc = let
    template = config.sops.templates;
    base = "NetworkManager/system-connections";
  in {
    "${base}/home.nmconnection".source = template."home.nmconnection".path;
    "${base}/eduroam.nmconnection".source = template."eduroam.nmconnection".path;
  };
  networking.networkmanager = {
    enable = true;
    ensureProfiles.profiles = {
      luhbotsNet5 = {
        connection = {
          id = "luhbotsNet5";
          type = "wifi";
          autoconnect-priority = "10";
        };
        wifi = {
          mode = "infrastructure";
          ssid = "luhbotsNet5";
        };
        wifi-security = {
          key-mgmt = "wpa-psk";
        };
      };
      luhbotsNet = {
        connection = {
          id = "luhbotsNet";
          type = "wifi";
          autoconnect-priority = "5";
        };
        wifi = {
          mode = "infrastructure";
          ssid = "luhbotsNet";
        };
        wifi-security = {
          key-mgmt = "wpa-psk";
        };
      };
    };
  };

  environment.systemPackages = with pkgs; [
    nm-tray
  ];
}
